@@ -50,18 +50,17 @@ def getVersionList(projectName):
 def getInstalledVersion(projectName, pipver='3'):
     try:
         cmd = 'pip' + pipver + ' freeze'
-        stdoutFile = 'tidal-dlversion-stdout.txt'
+        stdoutFile = 'piplibversion-stdout.txt'
         fp = open(stdoutFile, 'w')
         res = subprocess.call(cmd, shell=True, stdout=fp, stderr=fp)
         fp.close()
         txt = fileHelper.getFileContent(stdoutFile)
 
-        txt = 'tidal-dl==2020.6.28.2'
         lines = txt.split('\n')
         for item in lines:
-            if item.index(projectName + '==') == 0:
+            if item.find(projectName + '==') == 0:
                 version = item[len((projectName + '==')):]
                 return version
-    except:
+    except Exception as e:
         pass
-    return ''
\ No newline at end of file
+    return ''
